/*
//
//       Elvees Performance Platform
//           vector processing
//
*/

#pragma once

#include "eppv.h"

namespace eppv
{

/*
//  Name:        Copy
//  Purpose:     Copies data
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Copy(const epp_u8* pSrc, epp_u8* pDst, epp_size length)
{
    return eppv_Copy_u8(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_s8* pSrc, epp_s8* pDst, epp_size length)
{
    return eppv_Copy_s8(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_u16* pSrc, epp_u16* pDst, epp_size length)
{
    return eppv_Copy_u16(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_s16* pSrc, epp_s16* pDst, epp_size length)
{
    return eppv_Copy_s16(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_u32* pSrc, epp_u32* pDst, epp_size length)
{
    return eppv_Copy_u32(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_s32* pSrc, epp_s32* pDst, epp_size length)
{
    return eppv_Copy_s32(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_u64* pSrc, epp_u64* pDst, epp_size length)
{
    return eppv_Copy_u64(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_s64* pSrc, epp_s64* pDst, epp_size length)
{
    return eppv_Copy_s64(pSrc, pDst, length);
}

static inline epp_Status Copy_f16(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Copy_f16(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Copy_f32(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_f64* pSrc, epp_f64* pDst, epp_size length)
{
    return eppv_Copy_f64(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_cs16* pSrc, epp_cs16* pDst, epp_size length)
{
    return eppv_Copy_cs16(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_cs32* pSrc, epp_cs32* pDst, epp_size length)
{
    return eppv_Copy_cs32(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_cs64* pSrc, epp_cs64* pDst, epp_size length)
{
    return eppv_Copy_cs64(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_cf16* pSrc, epp_cf16* pDst, epp_size length)
{
    return eppv_Copy_cf16(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_cf32* pSrc, epp_cf32* pDst, epp_size length)
{
    return eppv_Copy_cf32(pSrc, pDst, length);
}

static inline epp_Status Copy(const epp_cf64* pSrc, epp_cf64* pDst, epp_size length)
{
    return eppv_Copy_cf64(pSrc, pDst, length);
}


/*
//  Name:        Set
//  Purpose:     Sets vector elements by const value
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    val        The value to set.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Set(epp_u8 val, epp_u8* pDst, epp_size length)
{
    return eppv_Set_u8(val, pDst, length);
}

static inline epp_Status Set(epp_s8 val, epp_s8* pDst, epp_size length)
{
    return eppv_Set_s8(val, pDst, length);
}

static inline epp_Status Set(epp_u16 val, epp_u16* pDst, epp_size length)
{
    return eppv_Set_u16(val, pDst, length);
}

static inline epp_Status Set(epp_s16 val, epp_s16* pDst, epp_size length)
{
    return eppv_Set_s16(val, pDst, length);
}

static inline epp_Status Set(epp_u32 val, epp_u32* pDst, epp_size length)
{
    return eppv_Set_u32(val, pDst, length);
}

static inline epp_Status Set(epp_s32 val, epp_s32* pDst, epp_size length)
{
    return eppv_Set_s32(val, pDst, length);
}

static inline epp_Status Set(epp_u64 val, epp_u64* pDst, epp_size length)
{
    return eppv_Set_u64(val, pDst, length);
}

static inline epp_Status Set(epp_s64 val, epp_s64* pDst, epp_size length)
{
    return eppv_Set_s64(val, pDst, length);
}

static inline epp_Status Set_f16(epp_f16 val, epp_f16* pDst, epp_size length)
{
    return eppv_Set_u16((epp_u16)val, (epp_u16*)pDst, length);
}

static inline epp_Status Set(epp_f32 val, epp_f32* pDst, epp_size length)
{
    return eppv_Set_f32(val, pDst, length);
}

static inline epp_Status Set(epp_f64 val, epp_f64* pDst, epp_size length)
{
    return eppv_Set_f64(val, pDst, length);
}

static inline epp_Status Set(epp_cs16 val, epp_cs16* pDst, epp_size length)
{
    return eppv_Set_cs16(val, pDst, length);
}

static inline epp_Status Set(epp_cs32 val, epp_cs32* pDst, epp_size length)
{
    return eppv_Set_cs32(val, pDst, length);
}

static inline epp_Status Set(epp_cs64 val, epp_cs64* pDst, epp_size length)
{
    return eppv_Set_cs64(val, pDst, length);
}

static inline epp_Status Set(epp_cf16 val, epp_cf16* pDst, epp_size length)
{
    return eppv_Set_cf16(val, pDst, length);
}

static inline epp_Status Set(epp_cf32 val, epp_cf32* pDst, epp_size length)
{
    return eppv_Set_cf32(val, pDst, length);
}

static inline epp_Status Set(epp_cf64 val, epp_cf64* pDst, epp_size length)
{
    return eppv_Set_cf64(val, pDst, length);
}


/*
//  Name:        Convert
//  Purpose:     Convert data
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vector.
//    roundMode  The round mode.
//  Notes:
*/
static inline epp_Status Convert(const epp_u8* pSrc, epp_u16* pDst, epp_size length)
{
    return  eppv_Convert_u8u16(pSrc, pDst, length);
}

static inline epp_Status Convert_u8f16(const epp_u8* pSrc, epp_f16* pDst, epp_size length)
{
    return  eppv_Convert_u8f16(pSrc, pDst, length);
}

static inline epp_Status Convert(const epp_u8* pSrc, epp_f32* pDst, epp_size length)
{
    return  eppv_Convert_u8f32(pSrc, pDst, length);
}

static inline epp_Status Convert(const epp_f16* pSrc, epp_s32* pDst, epp_size length, epp_RoundMode roundMode)
{
    return  eppv_Convert_f16s32(pSrc, pDst, length, roundMode);
}

static inline epp_Status Convert(const epp_f16* pSrc, epp_f32* pDst, epp_size length)
{
    return  eppv_Convert_f16f32(pSrc, pDst, length);
}

static inline epp_Status Convert(const epp_f32* pSrc, epp_f16* pDst, epp_size length)
{
    return  eppv_Convert_f32f16(pSrc, pDst, length);
}

static inline epp_Status Convert(const epp_u8* pSrc, epp_s16* pDst, epp_size length)
{
    return  eppv_Convert_u8s16(pSrc, pDst, length);
}


/*
//  Name:        MulAdd
//  Purpose:     Multiplies elements of two vectors and adds to elements of third vector (d = s1 * s2 + s3)
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc1      The sourse vector1 data pointer.
//    pSrc2      The sourse vector2 data pointer.
//    pSrc3      The sourse vector3 data pointer.
//    pDst       The destination vector data pointer.
//    pSrcDst    The source vector3 and destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status MulAdd(const epp_f16* pSrc1, const epp_f16* pSrc2, const epp_f16* pSrc3, epp_f16* pDst, epp_size length)
{
    return eppv_MulAdd_f16(pSrc1, pSrc2, pSrc3, pDst, length);
}

static inline epp_Status MulAdd(const epp_f32* pSrc1, const epp_f32* pSrc2, const epp_f32* pSrc3, epp_f32* pDst, epp_size length)
{
    return eppv_MulAdd_f32(pSrc1, pSrc2, pSrc3, pDst, length);
}

static inline epp_Status MulAdd(const epp_f64* pSrc1, const epp_f64* pSrc2, const epp_f64* pSrc3, epp_f64* pDst, epp_size length)
{
    return eppv_MulAdd_f64(pSrc1, pSrc2, pSrc3, pDst, length);
}


/*
//  Name:        MulCAdd
//  Purpose:     Multiplies elements of vector1 by value and adds to elements of second vector (d = s1 * v + s2)
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc1      The sourse vector1 data pointer.
//    pSrc2      The sourse vector2 data pointer.
//    vMul       The value to multiplicate first vector elements
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status MulCAdd(const epp_s16* pSrc1, epp_s16 vMul, const epp_s16* pSrc2, epp_s16* pDst, epp_size length, epp_size scale)
{
    return eppv_MulCAdd_s16_NS(pSrc1, vMul, pSrc2, pDst, length, scale);
}

static inline epp_Status MulCAdd(const epp_s32* pSrc1, epp_s32 vMul, const epp_s32* pSrc2, epp_s32* pDst, epp_size length, epp_size scale)
{
    return eppv_MulCAdd_s32_NS(pSrc1, vMul, pSrc2, pDst, length, scale);
}

static inline epp_Status MulCAdd(const epp_f16* pSrc1, epp_f16 vMul, const epp_f16* pSrc2, epp_f16* pDst, epp_size length)
{
    return eppv_MulCAdd_f16(pSrc1, vMul, pSrc2, pDst, length);
}

static inline epp_Status MulCAdd(const epp_f32* pSrc1, epp_f32 vMul, const epp_f32* pSrc2, epp_f32* pDst, epp_size length)
{
    return eppv_MulCAdd_f32(pSrc1, vMul, pSrc2, pDst, length);
}

static inline epp_Status MulCAdd(const epp_f64* pSrc1, epp_f64 vMul, const epp_f64* pSrc2, epp_f64* pDst, epp_size length)
{
    return eppv_MulCAdd_f64(pSrc1, vMul, pSrc2, pDst, length);
}


/*
//  Name:        MulCAddC
//  Purpose:     Normilize data (dst = src * vMul + vAdd)
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//    vMul       The value for multiplication.
//    vAdd       The value for addition.
//  Notes:
*/
static inline epp_Status MulCAddC(const epp_u8* pSrc, epp_f16 vMul, epp_f16 vAdd, epp_f16* pDst, epp_size length)
{
    return  eppv_MulCAddC_u8f16(pSrc, vMul, vAdd, pDst, length);
}

static inline epp_Status MulCAddC(const epp_u8* pSrc, epp_f32 vMul, epp_f32 vAdd, epp_f32* pDst, epp_size length)
{
    return  eppv_MulCAddC_u8f32(pSrc, vMul, vAdd, pDst, length);
}

static inline epp_Status MulCAddC(const epp_f16* pSrc, epp_f16 vMul, epp_f16 vAdd, epp_f16* pDst, epp_size length)
{
    return  eppv_MulCAddC_f16(pSrc, vMul, vAdd, pDst, length);
}

static inline epp_Status MulCAddC(const epp_f32* pSrc, epp_f32 vMul, epp_f32 vAdd, epp_f32* pDst, epp_size length)
{
    return  eppv_MulCAddC_f32(pSrc, vMul, vAdd, pDst, length);
}

static inline epp_Status MulCAddC(const epp_f64* pSrc, epp_f64 vMul, epp_f64 vAdd, epp_f64* pDst, epp_size length)
{
    return  eppv_MulCAddC_f64(pSrc, vMul, vAdd, pDst, length);
}

/*
//  Name:        Min, Max, MinMax
//  Purpose:     Finds min (and/or max) value of vector
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    length     The length of vector.
//    pMin       min value.
//    pMin       max value.
//  Notes:
*/
static inline epp_Status Min(const epp_u8* pSrc, epp_size length, epp_u8* pMin)
{
    return eppv_Min_u8(pSrc, length, pMin);
}

static inline epp_Status Min(const epp_s16* pSrc, epp_size length, epp_s16* pMin)
{
    return eppv_Min_s16(pSrc, length, pMin);
}

static inline epp_Status Min(const epp_s32* pSrc, epp_size length, epp_s32* pMin)
{
    return eppv_Min_s32(pSrc, length, pMin);
}

static inline epp_Status Min_f16(const epp_f16* pSrc, epp_size length, epp_f16* pMin)
{
    return eppv_Min_f16(pSrc, length, pMin);
}

static inline epp_Status Min(const epp_f32* pSrc, epp_size length, epp_f32* pMin)
{
    return eppv_Min_f32(pSrc, length, pMin);
}

static inline epp_Status Min(const epp_f64* pSrc, epp_size length, epp_f64* pMin)
{
    return eppv_Min_f64(pSrc, length, pMin);
}

static inline epp_Status Max(const epp_u8* pSrc, epp_size length, epp_u8* pMax)
{
    return eppv_Max_u8(pSrc, length, pMax);
}

static inline epp_Status Max(const epp_s16* pSrc, epp_size length, epp_s16* pMax)
{
    return eppv_Max_s16(pSrc, length, pMax);
}

static inline epp_Status Max(const epp_s32* pSrc, epp_size length, epp_s32* pMax)
{
    return eppv_Max_s32(pSrc, length, pMax);
}

static inline epp_Status Max_f16(const epp_f16* pSrc, epp_size length, epp_f16* pMax)
{
    return eppv_Max_f16(pSrc, length, pMax);
}

static inline epp_Status Max(const epp_f32* pSrc, epp_size length, epp_f32* pMax)
{
    return eppv_Max_f32(pSrc, length, pMax);
}

static inline epp_Status Max(const epp_f64* pSrc, epp_size length, epp_f64* pMax)
{
    return eppv_Max_f64(pSrc, length, pMax);
}

static inline epp_Status MinMax(const epp_u8* pSrc, epp_size length, epp_u8* pMin, epp_u8* pMax)
{
    return eppv_MinMax_u8(pSrc, length, pMin, pMax);
}

static inline epp_Status MinMax(const epp_s16* pSrc, epp_size length, epp_s16* pMin, epp_s16* pMax)
{
    return eppv_MinMax_s16(pSrc, length, pMin, pMax);
}

static inline epp_Status MinMax(const epp_s32* pSrc, epp_size length, epp_s32* pMin, epp_s32* pMax)
{
    return eppv_MinMax_s32(pSrc, length, pMin, pMax);
}

static inline epp_Status MinMax_f16(const epp_f16* pSrc, epp_size length, epp_f16* pMin, epp_f16* pMax)
{
    return eppv_MinMax_f16(pSrc, length, pMin, pMax);
}

static inline epp_Status MinMax(const epp_f32* pSrc, epp_size length, epp_f32* pMin, epp_f32* pMax)
{
    return eppv_MinMax_f32(pSrc, length, pMin, pMax);
}

static inline epp_Status MinMax(const epp_f64* pSrc, epp_size length, epp_f64* pMin, epp_f64* pMax)
{
    return eppv_MinMax_f64(pSrc, length, pMin, pMax);
}


/*
//  Name:        MinAbs, MaxAbs, MinMaxAbs
//  Purpose:     Finds min (and/or max) abs value of vector
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    length     The length of vector.
//    pMin       min abs value.
//    pMax       max abs value.
//  Notes:
*/
static inline epp_Status MinAbs(const epp_s16* pSrc, epp_size length, epp_u16* pMin)
{
    return eppv_MinAbs_s16(pSrc, length, pMin);
}

static inline epp_Status MinAbs(const epp_s32* pSrc, epp_size length, epp_u32* pMin)
{
    return eppv_MinAbs_s32(pSrc, length, pMin);
}

static inline epp_Status MinAbs(const epp_f16* pSrc, epp_size length, epp_f16* pMin)
{
    return eppv_MinAbs_f16(pSrc, length, pMin);
}

static inline epp_Status MinAbs(const epp_f32* pSrc, epp_size length, epp_f32* pMin)
{
    return eppv_MinAbs_f32(pSrc, length, pMin);
}

static inline epp_Status MinAbs(const epp_f64* pSrc, epp_size length, epp_f64* pMin)
{
    return eppv_MinAbs_f64(pSrc, length, pMin);
}

static inline epp_Status MaxAbs(const epp_s16* pSrc, epp_size length, epp_u16* pMin)
{
    return eppv_MaxAbs_s16(pSrc, length, pMin);
}

static inline epp_Status MaxAbs(const epp_s32* pSrc, epp_size length, epp_u32* pMin)
{
    return eppv_MaxAbs_s32(pSrc, length, pMin);
}

static inline epp_Status MaxAbs(const epp_f16* pSrc, epp_size length, epp_f16* pMin)
{
    return eppv_MaxAbs_f16(pSrc, length, pMin);
}

static inline epp_Status MaxAbs(const epp_f32* pSrc, epp_size length, epp_f32* pMin)
{
    return eppv_MaxAbs_f32(pSrc, length, pMin);
}

static inline epp_Status MaxAbs(const epp_f64* pSrc, epp_size length, epp_f64* pMin)
{
    return eppv_MaxAbs_f64(pSrc, length, pMin);
}

static inline epp_Status MinMaxAbs(const epp_s16* pSrc, epp_size length, epp_u16* pMin, epp_u16* pMax)
{
    return eppv_MinMaxAbs_s16(pSrc, length, pMin, pMax);
}

static inline epp_Status MinMaxAbs(const epp_s32* pSrc, epp_size length, epp_u32* pMin, epp_u32* pMax)
{
    return eppv_MinMaxAbs_s32(pSrc, length, pMin, pMax);
}

static inline epp_Status MinMaxAbs(const epp_f16* pSrc, epp_size length, epp_f16* pMin, epp_f16* pMax)
{
    return eppv_MinMaxAbs_f16(pSrc, length, pMin, pMax);
}

static inline epp_Status MinMaxAbs(const epp_f32* pSrc, epp_size length, epp_f32* pMin, epp_f32* pMax)
{
    return eppv_MinMaxAbs_f32(pSrc, length, pMin, pMax);
}

static inline epp_Status MinMaxAbs(const epp_f64* pSrc, epp_size length, epp_f64* pMin, epp_f64* pMax)
{
    return eppv_MinMaxAbs_f64(pSrc, length, pMin, pMax);
}


/*
//  Name:        MinAbsDiff, MaxAbsDiff, MinMaxAbsDiff
//  Purpose:     Finds min (and/or max) abs value of difference of two vectors
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc1      The first sourse vector data pointer.
//    pSrc2      The second sourse vector data pointer.
//    length     The length of vector.
//    pMin       min abs value of difference.
//    pMax       max abs value of difference.
//  Notes:
*/
static inline epp_Status MaxAbsDiff(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_size length, epp_f16* pMin)
{
    return eppv_MaxAbsDiff_f16(pSrc1, pSrc2, length, pMin);
}

static inline epp_Status MaxAbsDiff(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_size length, epp_f32* pMin)
{
    return eppv_MaxAbsDiff_f32(pSrc1, pSrc2, length, pMin);
}


/*
//  Name:        Mul
//  Purpose:     Multiplicatess vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc1      The sourse vector1 data pointer.
//    pSrc2      The sourse vector2 data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Mul_N(const epp_s16* pSrc1, const epp_s16* pSrc2, epp_s16* pDst, epp_size length, epp_size scale)
{
    return eppv_Mul_s16_N(pSrc1, pSrc2, pDst, length, scale);
}

static inline epp_Status Mul_NS(const epp_s16* pSrc1, const epp_s16* pSrc2, epp_s16* pDst, epp_size length, epp_size scale)
{
    return eppv_Mul_s16_NS(pSrc1, pSrc2, pDst, length, scale);
}

static inline epp_Status Mul_N(const epp_s32* pSrc1, const epp_s32* pSrc2, epp_s32* pDst, epp_size length, epp_size scale)
{
    return eppv_Mul_s32_N(pSrc1, pSrc2, pDst, length, scale);
}

static inline epp_Status Mul_NS(const epp_s32* pSrc1, const epp_s32* pSrc2, epp_s32* pDst, epp_size length, epp_size scale)
{
    return eppv_Mul_s32_NS(pSrc1, pSrc2, pDst, length, scale);
}

static inline epp_Status Mul(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_f16* pDst, epp_size length)
{
    return eppv_Mul_f16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Mul(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_f32* pDst, epp_size length)
{
    return eppv_Mul_f32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Mul(const epp_f64* pSrc1, const epp_f64* pSrc2, epp_f64* pDst, epp_size length)
{
    return eppv_Mul_f64(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Mul(const epp_cf16* pSrc1, const epp_cf16* pSrc2, epp_cf16* pDst, epp_size length)
{
    return eppv_Mul_cf16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Mul(const epp_cf32* pSrc1, const epp_cf32* pSrc2, epp_cf32* pDst, epp_size length)
{
    return eppv_Mul_cf32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Mul(const epp_cf64* pSrc1, const epp_cf64* pSrc2, epp_cf64* pDst, epp_size length)
{
    return eppv_Mul_cf64(pSrc1, pSrc2, pDst, length);
}


/*
//  Name:        MulC
//  Purpose:     Multiplicates vectors elements by value
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    val        The value to multiply.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status MulC_N(const epp_s16* pSrc, epp_s16 val, epp_s16* pDst, epp_size length, epp_size scale)
{
    return eppv_MulC_s16_N(pSrc, val, pDst, length, scale);
}

static inline epp_Status MulC_NS(const epp_s16* pSrc, epp_s16 val, epp_s16* pDst, epp_size length, epp_size scale)
{
    return eppv_MulC_s16_NS(pSrc, val, pDst, length, scale);
}

static inline epp_Status MulC_N(const epp_s32* pSrc, epp_s32 val, epp_s32* pDst, epp_size length, epp_size scale)
{
    return eppv_MulC_s32_N(pSrc, val, pDst, length, scale);
}

static inline epp_Status MulC_NS(const epp_s32* pSrc, epp_s32 val, epp_s32* pDst, epp_size length, epp_size scale)
{
    return eppv_MulC_s32_NS(pSrc, val, pDst, length, scale);
}

static inline epp_Status MulC(const epp_f16* pSrc, epp_f16 val, epp_f16* pDst, epp_size length)
{
    return eppv_MulC_f16(pSrc, val, pDst, length);
}

static inline epp_Status MulC(const epp_f32* pSrc, epp_f32 val, epp_f32* pDst, epp_size length)
{
    return eppv_MulC_f32(pSrc, val, pDst, length);
}

static inline epp_Status MulC(const epp_f64* pSrc, epp_f64 val, epp_f64* pDst, epp_size length)
{
    return eppv_MulC_f64(pSrc, val, pDst, length);
}

static inline epp_Status MulC(const epp_cf16* pSrc, epp_cf16 val, epp_cf16* pDst, epp_size length)
{
    return eppv_MulC_cf16(pSrc, val, pDst, length);
}

static inline epp_Status MulC(const epp_cf32* pSrc, epp_cf32 val, epp_cf32* pDst, epp_size length)
{
    return eppv_MulC_cf32(pSrc, val, pDst, length);
}

static inline epp_Status MulC(const epp_cf64* pSrc, epp_cf64 val, epp_cf64* pDst, epp_size length)
{
    return eppv_MulC_cf64(pSrc, val, pDst, length);
}


/*
//  Name:        Div
//  Purpose:     Divides vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc1      The sourse vector1 data pointer.
//    pSrc2      The sourse vector2 data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Div(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_f16* pDst, epp_size length)
{
    return eppv_Div_f16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Div(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_f32* pDst, epp_size length)
{
    return eppv_Div_f32(pSrc1, pSrc2, pDst, length);
}


/*
//  Name:        Add
//  Purpose:     Adds vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc1      The sourse vector1 data pointer.
//    pSrc2      The sourse vector2 data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Add(const epp_s16* pSrc1, const epp_s16* pSrc2, epp_s16* pDst, epp_size length)
{
    return eppv_Add_s16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add_S(const epp_s16* pSrc1, const epp_s16* pSrc2, epp_s16* pDst, epp_size length)
{
    return eppv_Add_s16_S(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add(const epp_s32* pSrc1, const epp_s32* pSrc2, epp_s32* pDst, epp_size length)
{
    return eppv_Add_s32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add_S(const epp_s32* pSrc1, const epp_s32* pSrc2, epp_s32* pDst, epp_size length)
{
    return eppv_Add_s32_S(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add_f16(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_f16* pDst, epp_size length)
{
    return eppv_Add_f16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_f32* pDst, epp_size length)
{
    return eppv_Add_f32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add(const epp_f64* pSrc1, const epp_f64* pSrc2, epp_f64* pDst, epp_size length)
{
    return eppv_Add_f64(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add(const epp_cs16* pSrc1, const epp_cs16* pSrc2, epp_cs16* pDst, epp_size length)
{
    return eppv_Add_cs16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add_S(const epp_cs16* pSrc1, const epp_cs16* pSrc2, epp_cs16* pDst, epp_size length)
{
    return eppv_Add_cs16_S(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add(const epp_cs32* pSrc1, const epp_cs32* pSrc2, epp_cs32* pDst, epp_size length)
{
    return eppv_Add_cs32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add_S(const epp_cs32* pSrc1, const epp_cs32* pSrc2, epp_cs32* pDst, epp_size length)
{
    return eppv_Add_cs32_S(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add(const epp_cf16* pSrc1, const epp_cf16* pSrc2, epp_cf16* pDst, epp_size length)
{
    return eppv_Add_cf16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add(const epp_cf32* pSrc1, const epp_cf32* pSrc2, epp_cf32* pDst, epp_size length)
{
    return eppv_Add_cf32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Add(const epp_cf64* pSrc1, const epp_cf64* pSrc2, epp_cf64* pDst, epp_size length)
{
    return eppv_Add_cf64(pSrc1, pSrc2, pDst, length);
}


/*
//  Name:        AddC
//  Purpose:     Adds vector elemets to const
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    cAdd       The const value.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status AddC(const epp_s16* pSrc, epp_s16 cAdd, epp_s16* pDst, epp_size length)
{
    return eppv_AddC_s16(pSrc, cAdd, pDst, length);
}
static inline epp_Status AddC_S(const epp_s16* pSrc, epp_s16 cAdd, epp_s16* pDst, epp_size length)
{
    return eppv_AddC_s16_S(pSrc, cAdd, pDst, length);
}
static inline epp_Status AddC(const epp_s32* pSrc, epp_s32 cAdd, epp_s32* pDst, epp_size length)
{
    return eppv_AddC_s32(pSrc, cAdd, pDst, length);
}
static inline epp_Status AddC_S(const epp_s32* pSrc, epp_s32 cAdd, epp_s32* pDst, epp_size length)
{
    return eppv_AddC_s32_S(pSrc, cAdd, pDst, length);
}
static inline epp_Status AddC_f16(const epp_f16* pSrc, epp_f16 cAdd, epp_f16* pDst, epp_size length)
{
    return eppv_AddC_f16(pSrc, cAdd, pDst, length);
}
static inline epp_Status AddC(const epp_f32* pSrc, epp_f32 cAdd, epp_f32* pDst, epp_size length)
{
    return eppv_AddC_f32(pSrc, cAdd, pDst, length);
}
static inline epp_Status AddC(const epp_f64* pSrc, epp_f64 cAdd, epp_f64* pDst, epp_size length)
{
    return eppv_AddC_f64(pSrc, cAdd, pDst, length);
}


/*
//  Name:        Sub
//  Purpose:     Subtracs vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc1      The sourse vector1 data pointer.
//    pSrc2      The sourse vector2 data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Sub(const epp_s16* pSrc1, const epp_s16* pSrc2, epp_s16* pDst, epp_size length)
{
    return eppv_Sub_s16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub_S(const epp_s16* pSrc1, const epp_s16* pSrc2, epp_s16* pDst, epp_size length)
{
    return eppv_Sub_s16_S(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub(const epp_s32* pSrc1, const epp_s32* pSrc2, epp_s32* pDst, epp_size length)
{
    return eppv_Sub_s32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub_S(const epp_s32* pSrc1, const epp_s32* pSrc2, epp_s32* pDst, epp_size length)
{
    return eppv_Sub_s32_S(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub_f16(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_f16* pDst, epp_size length)
{
    return eppv_Sub_f16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_f32* pDst, epp_size length)
{
    return eppv_Sub_f32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub(const epp_f64* pSrc1, const epp_f64* pSrc2, epp_f64* pDst, epp_size length)
{
    return eppv_Sub_f64(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub(const epp_cs16* pSrc1, const epp_cs16* pSrc2, epp_cs16* pDst, epp_size length)
{
    return eppv_Sub_cs16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub_S(const epp_cs16* pSrc1, const epp_cs16* pSrc2, epp_cs16* pDst, epp_size length)
{
    return eppv_Sub_cs16_S(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub(const epp_cs32* pSrc1, const epp_cs32* pSrc2, epp_cs32* pDst, epp_size length)
{
    return eppv_Sub_cs32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub_S(const epp_cs32* pSrc1, const epp_cs32* pSrc2, epp_cs32* pDst, epp_size length)
{
    return eppv_Sub_cs32_S(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub(const epp_cf16* pSrc1, const epp_cf16* pSrc2, epp_cf16* pDst, epp_size length)
{
    return eppv_Sub_cf16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub(const epp_cf32* pSrc1, const epp_cf32* pSrc2, epp_cf32* pDst, epp_size length)
{
    return eppv_Sub_cf32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Sub(const epp_cf64* pSrc1, const epp_cf64* pSrc2, epp_cf64* pDst, epp_size length)
{
    return eppv_Sub_cf64(pSrc1, pSrc2, pDst, length);
}


/*
//  Name:        CSub
//  Purpose:     Subtracs vector elemets from const
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    cSub       The const value.
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status CSub(epp_s16 cSub, const epp_s16* pSrc, epp_s16* pDst, epp_size length)
{
    return eppv_CSub_s16(cSub, pSrc, pDst, length);
}

static inline epp_Status CSub_S(epp_s16 cSub, const epp_s16* pSrc, epp_s16* pDst, epp_size length)
{
    return eppv_CSub_s16_S(cSub, pSrc, pDst, length);
}

static inline epp_Status CSub(epp_s32 cSub, const epp_s32* pSrc, epp_s32* pDst, epp_size length)
{
    return eppv_CSub_s32(cSub, pSrc, pDst, length);
}

static inline epp_Status CSub_S(epp_s32 cSub, const epp_s32* pSrc, epp_s32* pDst, epp_size length)
{
    return eppv_CSub_s32_S(cSub, pSrc, pDst, length);
}

static inline epp_Status CSub_f16(epp_f16 cSub, const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_CSub_f16(cSub, pSrc, pDst, length);
}

static inline epp_Status CSub(epp_f32 cSub, const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_CSub_f32(cSub, pSrc, pDst, length);
}

static inline epp_Status CSub(epp_f64 cSub, const epp_f64* pSrc, epp_f64* pDst, epp_size length)
{
    return eppv_CSub_f64(cSub, pSrc, pDst, length);
}


/*
//  Name:        Neg
//  Purpose:     Negatives vector elemets
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Neg(const epp_s16* pSrc, epp_s16* pDst, epp_size length)
{
    return eppv_Neg_s16(pSrc, pDst, length);
}

static inline epp_Status Neg_S(const epp_s16* pSrc, epp_s16* pDst, epp_size length)
{
    return eppv_Neg_s16_S(pSrc, pDst, length);
}

static inline epp_Status Neg(const epp_s32* pSrc, epp_s32* pDst, epp_size length)
{
    return eppv_Neg_s32(pSrc, pDst, length);
}

static inline epp_Status Neg_S(const epp_s32* pSrc, epp_s32* pDst, epp_size length)
{
    return eppv_Neg_s32_S(pSrc, pDst, length);
}

static inline epp_Status Neg_f16(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Neg_f16(pSrc, pDst, length);
}

static inline epp_Status Neg(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Neg_f32(pSrc, pDst, length);
}

static inline epp_Status Neg(const epp_f64* pSrc, epp_f64* pDst, epp_size length)
{
    return eppv_Neg_f64(pSrc, pDst, length);
}


/*
//  Name:        Sum
//  Purpose:     Calculates the sum of vector elements
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    length     The length of vector.
//    pSum       The sum of values.
//  Notes:
*/
static inline epp_Status Sum(const epp_s16* pSrc, epp_size length, epp_s64* pSum)
{
    return eppv_Sum_s16(pSrc, length, pSum);
}

static inline epp_Status Sum(const epp_s32* pSrc, epp_size length, epp_s64* pSum)
{
    return eppv_Sum_s32(pSrc, length, pSum);
}

static inline epp_Status Sum(const epp_f16* pSrc, epp_size length, epp_f32* pSum)
{
    return eppv_Sum_f16(pSrc, length, pSum);
}

static inline epp_Status Sum(const epp_f32* pSrc, epp_size length, epp_f32* pSum)
{
    return eppv_Sum_f32(pSrc, length, pSum);
}

static inline epp_Status Sum(const epp_f64* pSrc, epp_size length, epp_f64* pSum)
{
    return eppv_Sum_f64(pSrc, length, pSum);
}

static inline epp_Status Sum(const epp_cf16* pSrc, epp_size length, epp_cf32* pSum)
{
    return eppv_Sum_cf16(pSrc, length, pSum);
}

static inline epp_Status Sum(const epp_cf32* pSrc, epp_size length, epp_cf32* pSum)
{
    return eppv_Sum_cf32(pSrc, length, pSum);
}

static inline epp_Status Sum(const epp_cf64* pSrc, epp_size length, epp_cf64* pSum)
{
    return eppv_Sum_cf64(pSrc, length, pSum);
}


/*
//  Name:        SumAbs
//  Purpose:     Calculates the sum of vector absolute elements
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    length     The length of vector.
//    pSum       The sum of values.
//  Notes:
*/
static inline epp_Status SumAbs(const epp_s16* pSrc, epp_size length, epp_u64* pSum)
{
    return eppv_SumAbs_s16(pSrc, length, pSum);
}

static inline epp_Status SumAbs(const epp_s32* pSrc, epp_size length, epp_u64* pSum)
{
    return eppv_SumAbs_s32(pSrc, length, pSum);
}

static inline epp_Status SumAbs(const epp_f16* pSrc, epp_size length, epp_f32* pSum)
{
    return eppv_SumAbs_f16(pSrc, length, pSum);
}

static inline epp_Status SumAbs(const epp_f32* pSrc, epp_size length, epp_f32* pSum)
{
    return eppv_SumAbs_f32(pSrc, length, pSum);
}

static inline epp_Status SumAbs(const epp_f64* pSrc, epp_size length, epp_f64* pSum)
{
    return eppv_SumAbs_f64(pSrc, length, pSum);
}


/*
//  Name:        SumSqr
//  Purpose:     Calculates the sum of squares of vector elements
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    length     The length of vector.
//    pSum       The sum of values.
//  Notes:
*/
static inline epp_Status SumSqr(const epp_s16* pSrc, epp_size length, epp_u64* pSum)
{
    return eppv_SumSqr_s16(pSrc, length, pSum);
}

static inline epp_Status SumSqr(const epp_s32* pSrc, epp_size length, epp_u64* pSum, epp_size scale)
{
    return eppv_SumSqr_s32_N(pSrc, length, pSum, scale);
}

static inline epp_Status SumSqr(const epp_f16* pSrc, epp_size length, epp_f32* pSum)
{
    return eppv_SumSqr_f16(pSrc, length, pSum);
}

static inline epp_Status SumSqr(const epp_f32* pSrc, epp_size length, epp_f32* pSum)
{
    return eppv_SumSqr_f32(pSrc, length, pSum);
}

static inline epp_Status SumSqr(const epp_f64* pSrc, epp_size length, epp_f64* pSum)
{
    return eppv_SumSqr_f64(pSrc, length, pSum);
}


/*
//  Name:        SumSqrAbs
//  Purpose:     Calculates the sum of squares of absolute values of vector elements
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    length     The length of vector.
//    pSum       The sum of values.
//  Notes:
*/
static inline epp_Status SumSqrAbs(const epp_cs16* pSrc, epp_size length, epp_u64* pSum)
{
    return eppv_SumSqrAbs_cs16(pSrc, length, pSum);
}

static inline epp_Status SumSqrAbs_N(const epp_cs32* pSrc, epp_size length, epp_u64* pSum, epp_size scale)
{
    return eppv_SumSqrAbs_cs32_N(pSrc, length, pSum, scale);
}

static inline epp_Status SumSqrAbs(const epp_cf16* pSrc, epp_size length, epp_f32* pSum)
{
    return eppv_SumSqrAbs_cf16(pSrc, length, pSum);
}

static inline epp_Status SumSqrAbs(const epp_cf32* pSrc, epp_size length, epp_f32* pSum)
{
    return eppv_SumSqrAbs_cf32(pSrc, length, pSum);
}

static inline epp_Status SumSqrAbs(const epp_cf64* pSrc, epp_size length, epp_f64* pSum)
{
    return eppv_SumSqrAbs_cf64(pSrc, length, pSum);
}


/*
//  Name:        SumAbsDiff
//  Purpose:     Calculates the sum of absolute values of differences of elements of two vectors
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc1      The first sourse vector data pointer.
//    pSrc2      The second sourse vector data pointer.
//    length     The length of vector.
//    pSum       The sum of values.
//  Notes:
*/
static inline epp_Status SumAbsDiff(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_size length, epp_f32* pSum)
{
    return eppv_SumAbsDiff_f16(pSrc1, pSrc2, length, pSum);
}

static inline epp_Status SumAbsDiff_f32(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_size length, epp_f32* pSum)
{
    return eppv_SumAbsDiff_f32(pSrc1, pSrc2, length, pSum);
}


/*
//  Name:        SumSqrDiff
//  Purpose:     Calculates the sum of squared differences of elements of two vectors
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc1      The first sourse vector data pointer.
//    pSrc2      The second sourse vector data pointer.
//    length     The length of vector.
//    pSum       The sum of values.
//  Notes:
*/
static inline epp_Status SumSqrDiff(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_size length, epp_f32* pSum)
{
    return eppv_SumSqrDiff_f16(pSrc1, pSrc2, length, pSum);
}

static inline epp_Status SumSqrDiff_f32(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_size length, epp_f32* pSum)
{
    return eppv_SumSqrDiff_f32(pSrc1, pSrc2, length, pSum);
}


/*
//  Name:        DotProd
//  Purpose:     Calculates the dot product of two vectors
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc1      The sourse vector data pointer.
//    pSrc2      The sourse vector data pointer.
//    length     The length of vector.
//    pDp        The pointer to result.
//    scale      The scale factor.
//  Notes:
*/
static inline epp_Status DotProd(const epp_s16* pSrc1, const epp_s16* pSrc2, epp_size length, epp_u64* pDp)
{
    return eppv_DotProd_s16(pSrc1, pSrc2, length, pDp);
}

static inline epp_Status DotProd(const epp_s32* pSrc1, const epp_s32* pSrc2, epp_size length, epp_u64* pDp, epp_size scale)
{
    return eppv_DotProd_s32_N(pSrc1, pSrc2, length, pDp, scale);
}

static inline epp_Status DotProd(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_size length, epp_f32* pDp)
{
    return eppv_DotProd_f16(pSrc1, pSrc2, length, pDp);
}

static inline epp_Status DotProd(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_size length, epp_f32* pDp)
{
    return eppv_DotProd_f32(pSrc1, pSrc2, length, pDp);
}

static inline epp_Status DotProd(const epp_f64* pSrc1, const epp_f64* pSrc2, epp_size length, epp_f64* pDp)
{
    return eppv_DotProd_f64(pSrc1, pSrc2, length, pDp);
}

static inline epp_Status DotProd(const epp_cf16* pSrc1, const epp_cf16* pSrc2, epp_size length, epp_cf32* pDp)
{
    return eppv_DotProd_cf16(pSrc1, pSrc2, length, pDp);
}

static inline epp_Status DotProd(const epp_cf32* pSrc1, const epp_cf32* pSrc2, epp_size length, epp_cf32* pDp)
{
    return eppv_DotProd_cf32(pSrc1, pSrc2, length, pDp);
}

static inline epp_Status DotProd(const epp_cf64* pSrc1, const epp_cf64* pSrc2, epp_size length, epp_cf64* pDp)
{
    return eppv_DotProd_cf64(pSrc1, pSrc2, length, pDp);
}


/*
//  Name:        Abs
//  Purpose:     Calculates abs value of vector elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Abs_S(const epp_s16* pSrc, epp_s16* pDst, epp_size length)
{
    return eppv_Abs_s16_S(pSrc, pDst, length);
}

static inline epp_Status Abs(const epp_s16* pSrc, epp_u16* pDst, epp_size length)
{
    return eppv_Abs_s16u16(pSrc, pDst, length);
}

static inline epp_Status Abs_S(const epp_s32* pSrc, epp_s32* pDst, epp_size length)
{
    return eppv_Abs_s32_S(pSrc, pDst, length);
}

static inline epp_Status Abs(const epp_s32* pSrc, epp_u32* pDst, epp_size length)
{
    return eppv_Abs_s32u32(pSrc, pDst, length);
}

static inline epp_Status Abs(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Abs_f16(pSrc, pDst, length);
}

static inline epp_Status Abs(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Abs_f32(pSrc, pDst, length);
}

static inline epp_Status Abs(const epp_f64* pSrc, epp_f64* pDst, epp_size length)
{
    return eppv_Abs_f64(pSrc, pDst, length);
}


/*
//  Name:         Sqr
//  Purpose:      Calculates squared values of vectors elements
//  Returns:      epp_Status
//    epp_StsOK   Ok
//  Parameters:
//    pSrc        The sourse vector data pointer.
//    pDst        The destination vector data pointer.
//    length      The length of vectors.
//  Notes:
*/
static inline epp_Status Sqr(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Sqr_f16(pSrc, pDst, length);
}

static inline epp_Status Sqr(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Sqr_f32(pSrc, pDst, length);
}

static inline epp_Status Sqr(const epp_f64* pSrc, epp_f64* pDst, epp_size length)
{
    return eppv_Sqr_f64(pSrc, pDst, length);
}


/*
//  Name:         SqrAbs
//  Purpose:      Calculates squared absolute values of vectors elements
//  Returns:      epp_Status
//    epp_StsOK   Ok
//  Parameters:
//    pSrc        The sourse vector data pointer.
//    pDst        The destination vector data pointer.
//    length      The length of vectors.
//  Notes:
*/
static inline epp_Status SqrAbs(const epp_cf16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_SqrAbs_cf16(pSrc, pDst, length);
}

static inline epp_Status SqrAbs(const epp_cf32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_SqrAbs_cf32(pSrc, pDst, length);
}

static inline epp_Status SqrAbs(const epp_cf64* pSrc, epp_f64* pDst, epp_size length)
{
    return eppv_SqrAbs_cf64(pSrc, pDst, length);
}


/*
//  Name:        Sqrt
//  Purpose:     Calculates square root of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Sqrt(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Sqrt_f16(pSrc, pDst, length);
}

static inline epp_Status Sqrt(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Sqrt_f32(pSrc, pDst, length);
}


/*
//  Name:        Exp
//  Purpose:     Calculates exp of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Exp(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Exp_f16(pSrc, pDst, length);
}

static inline epp_Status Exp(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Exp_f32(pSrc, pDst, length);
}

static inline epp_Status Exp(const epp_cf16* pSrc, epp_cf16* pDst, epp_size length)
{
    return eppv_Exp_cf16(pSrc, pDst, length);
}

static inline epp_Status Exp(const epp_cf32* pSrc, epp_cf32* pDst, epp_size length)
{
    return eppv_Exp_cf32(pSrc, pDst, length);
}


/*
//  Name:        Log
//  Purpose:     Calculates log of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Log(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Log_f16(pSrc, pDst, length);
}

static inline epp_Status Log(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Log_f32(pSrc, pDst, length);
}


/*
//  Name:        Sin
//  Purpose:     Calculates sin of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Sin(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Sin_f16(pSrc, pDst, length);
}

static inline epp_Status Sin(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Sin_f32(pSrc, pDst, length);
}


/*
//  Name:        Sinh
//  Purpose:     Calculates sinh of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Sinh(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Sinh_f16(pSrc, pDst, length);
}

static inline epp_Status Sinh(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Sinh_f32(pSrc, pDst, length);
}


/*
//  Name:        Asinh
//  Purpose:     Calculates asinh of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Asinh(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Asinh_f16(pSrc, pDst, length);
}

static inline epp_Status Asinh(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Asinh_f32(pSrc, pDst, length);
}


/*
//  Name:        Acosh
//  Purpose:     Calculates acosh of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Acosh(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Acosh_f16(pSrc, pDst, length);
}

static inline epp_Status Acosh(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Acosh_f32(pSrc, pDst, length);
}


/*
//  Name:        Cos
//  Purpose:     Calculates cos of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Cos(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Cos_f16(pSrc, pDst, length);
}

static inline epp_Status Cos(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Cos_f32(pSrc, pDst, length);
}


/*
//  Name:        Cosh
//  Purpose:     Calculates cosh of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Cosh(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Cosh_f16(pSrc, pDst, length);
}

static inline epp_Status Cosh(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Cosh_f32(pSrc, pDst, length);
}


/*
//  Name:        Asin
//  Purpose:     Calculates arcsin of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Asin(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Asin_f16(pSrc, pDst, length);
}

static inline epp_Status Asin(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Asin_f32(pSrc, pDst, length);
}


/*
//  Name:        Acos
//  Purpose:     Calculates arcsin of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Acos(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Acos_f16(pSrc, pDst, length);
}

static inline epp_Status Acos(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Acos_f32(pSrc, pDst, length);
}


/*
//  Name:        Atan
//  Purpose:     Calculates arctan of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Atan(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Atan_f16(pSrc, pDst, length);
}

static inline epp_Status Atan(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Atan_f32(pSrc, pDst, length);
}
/*
//  Name:        Atan2
//  Purpose:     Calculates Atan2 of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/

static inline epp_Status Atan2(const epp_f32* pSrcIm, const epp_f32* pSrcRe, epp_f32* pDst, epp_size length)
{
    return eppv_Atan2_f32( pSrcIm, pSrcRe, pDst, length);
}
static inline epp_Status Atan2(const epp_cf32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Atan2_cf32f32( pSrc, pDst, length);
}

/*
//  Name:        Tan
//  Purpose:     Calculates tangent of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Tan(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Tan_f16(pSrc, pDst, length);
}

static inline epp_Status Tan(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Tan_f32(pSrc, pDst, length);
}


/*
//  Name:        eppv_Tanh
//  Purpose:     Calculates hyperbolic tangent of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Tanh(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Tanh_f16(pSrc, pDst, length);
}

static inline epp_Status Tanh(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Tanh_f32(pSrc, pDst, length);
}


/*
//  Name:        eppv_Atanh
//  Purpose:     Calculates inverse hyperbolic tangent of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Atanh(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Atanh_f16(pSrc, pDst, length);
}

static inline epp_Status Atanh(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Atanh_f32(pSrc, pDst, length);
}


/*
//  Name:        eppv_Pow
//  Purpose:     Calculates pow of vectors elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc1       The sourse vector data pointer.
//    pSrc2       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Pow(const epp_f16* pSrc1,const epp_f16* pSrc2, epp_f16* pDst, epp_size length)
{
    return eppv_Pow_f16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Pow(const epp_f32* pSrc1,const epp_f32* pSrc2, epp_f32* pDst, epp_size length)
{
    return eppv_Pow_f32(pSrc1, pSrc2, pDst, length);
}

/*
//  Name:       eppv_PowC
//  Purpose:    Computes src raised to the val_th power. (dst = src^val)
//  Context:
//  Returns:    epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    val        The value to pow.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status PowC(const epp_f16* pSrc, epp_f16 val, epp_f16* pDst, epp_size length)
{
    return eppv_PowC_f16(pSrc, val, pDst, length);
}

static inline epp_Status PowC(const epp_f32* pSrc, epp_f32 val, epp_f32* pDst, epp_size length)
{
    return eppv_PowC_f32(pSrc, val, pDst, length);
}


/*
//  Name:        And/Or/Xor/Not
//  Purpose:     Computes the bitwise And/Or/Xor/Not of vectors
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc1      The sourse vector data pointer.
//    pSrc2      The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status And(const epp_u8* pSrc1, const epp_u8* pSrc2, epp_u8* pDst, epp_size length)
{
    return eppv_And_u8(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Or(const epp_u8* pSrc1, const epp_u8* pSrc2, epp_u8* pDst, epp_size length)
{
    return eppv_Or_u8(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Xor(const epp_u8* pSrc1, const epp_u8* pSrc2, epp_u8* pDst, epp_size length)
{
    return eppv_Xor_u8(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Not(const epp_u8* pSrc, epp_u8* pDst, epp_size length)
{
    return eppv_Not_u8(pSrc, pDst, length);
}

static inline epp_Status And(const epp_s8* pSrc1, const epp_s8* pSrc2, epp_s8* pDst, epp_size length)
{
    return eppv_And_s8(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status And(const epp_s16* pSrc1, const epp_s16* pSrc2, epp_s16* pDst, epp_size length)
{
    return eppv_And_s16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status And(const epp_u16* pSrc1, const epp_u16* pSrc2, epp_u16* pDst, epp_size length)
{
    return eppv_And_u16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status And(const epp_s32* pSrc1, const epp_s32* pSrc2, epp_s32* pDst, epp_size length)
{
    return eppv_And_s32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status And(const epp_u32* pSrc1, const epp_u32* pSrc2, epp_u32* pDst, epp_size length)
{
    return eppv_And_u32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status And(const epp_s64* pSrc1, const epp_s64* pSrc2, epp_s64* pDst, epp_size length)
{
    return eppv_And_s64(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status And(const epp_u64* pSrc1, const epp_u64* pSrc2, epp_u64* pDst, epp_size length)
{
    return eppv_And_u64(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status And(const epp_cs16* pSrc1, const epp_cs16* pSrc2, epp_cs16* pDst, epp_size length)
{
    return eppv_And_cs16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status And(const epp_cs32* pSrc1, const epp_cs32* pSrc2, epp_cs32* pDst, epp_size length)
{
    return eppv_And_cs32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Or(const epp_s8* pSrc1, const epp_s8* pSrc2, epp_s8* pDst, epp_size length)
{
    return eppv_Or_s8(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Or(const epp_s16* pSrc1, const epp_s16* pSrc2, epp_s16* pDst, epp_size length)
{
    return eppv_Or_s16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Or(const epp_u16* pSrc1, const epp_u16* pSrc2, epp_u16* pDst, epp_size length)
{
    return eppv_Or_u16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Or(const epp_s32* pSrc1, const epp_s32* pSrc2, epp_s32* pDst, epp_size length)
{
    return eppv_Or_s32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Or(const epp_u32* pSrc1, const epp_u32* pSrc2, epp_u32* pDst, epp_size length)
{
    return eppv_Or_u32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Or(const epp_s64* pSrc1, const epp_s64* pSrc2, epp_s64* pDst, epp_size length)
{
    return eppv_Or_s64(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Or(const epp_u64* pSrc1, const epp_u64* pSrc2, epp_u64* pDst, epp_size length)
{
    return eppv_Or_u64(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Or(const epp_cs16* pSrc1, const epp_cs16* pSrc2, epp_cs16* pDst, epp_size length)
{
    return eppv_Or_cs16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Or(const epp_cs32* pSrc1, const epp_cs32* pSrc2, epp_cs32* pDst, epp_size length)
{
    return eppv_Or_cs32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Xor(const epp_s8* pSrc1, const epp_s8* pSrc2, epp_s8* pDst, epp_size length)
{
    return eppv_Xor_s8(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Xor(const epp_s16* pSrc1, const epp_s16* pSrc2, epp_s16* pDst, epp_size length)
{
    return eppv_Xor_s16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Xor(const epp_u16* pSrc1, const epp_u16* pSrc2, epp_u16* pDst, epp_size length)
{
    return eppv_Xor_u16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Xor(const epp_s32* pSrc1, const epp_s32* pSrc2, epp_s32* pDst, epp_size length)
{
    return eppv_Xor_s32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Xor(const epp_u32* pSrc1, const epp_u32* pSrc2, epp_u32* pDst, epp_size length)
{
    return eppv_Xor_u32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Xor(const epp_s64* pSrc1, const epp_s64* pSrc2, epp_s64* pDst, epp_size length)
{
    return eppv_Xor_s64(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Xor(const epp_u64* pSrc1, const epp_u64* pSrc2, epp_u64* pDst, epp_size length)
{
    return eppv_Xor_u64(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Xor(const epp_cs16* pSrc1, const epp_cs16* pSrc2, epp_cs16* pDst, epp_size length)
{
    return eppv_Xor_cs16(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Xor(const epp_cs32* pSrc1, const epp_cs32* pSrc2, epp_cs32* pDst, epp_size length)
{
    return eppv_Xor_cs32(pSrc1, pSrc2, pDst, length);
}

static inline epp_Status Not(const epp_s8* pSrc, epp_s8* pDst, epp_size length)
{
    return eppv_Not_s8(pSrc, pDst, length);
}

static inline epp_Status Not(const epp_s16* pSrc, epp_s16* pDst, epp_size length)
{
    return eppv_Not_s16(pSrc, pDst, length);
}

static inline epp_Status Not(const epp_u16* pSrc, epp_u16* pDst, epp_size length)
{
    return eppv_Not_u16(pSrc, pDst, length);
}

static inline epp_Status Not(const epp_s32* pSrc, epp_s32* pDst, epp_size length)
{
    return eppv_Not_s32(pSrc, pDst, length);
}

static inline epp_Status Not(const epp_u32* pSrc, epp_u32* pDst, epp_size length)
{
    return eppv_Not_u32(pSrc, pDst, length);
}

static inline epp_Status Not(const epp_s64* pSrc, epp_s64* pDst, epp_size length)
{
    return eppv_Not_s64(pSrc, pDst, length);
}

static inline epp_Status Not(const epp_u64* pSrc, epp_u64* pDst, epp_size length)
{
    return eppv_Not_u64(pSrc, pDst, length);
}

static inline epp_Status Not(const epp_cs16* pSrc, epp_cs16* pDst, epp_size length)
{
    return eppv_Not_cs16(pSrc, pDst, length);
}

static inline epp_Status Not(const epp_cs32* pSrc, epp_cs32* pDst, epp_size length)
{
    return eppv_Not_cs32(pSrc, pDst, length);
}


/*
//  Name:        AndC/OrC/XorC
//  Purpose:     Computes the bitwise And/Or/Xor/Not of vector and value
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    val        The const value.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status AndC(const epp_u8* pSrc, epp_u8 val, epp_u8* pDst, epp_size length)
{
    return eppv_AndC_u8(pSrc, val, pDst, length);
}

static inline epp_Status AndC(const epp_u16* pSrc, epp_u16 val, epp_u16* pDst, epp_size length)
{
    return eppv_AndC_u16(pSrc, val, pDst, length);
}

static inline epp_Status AndC(const epp_u32* pSrc, epp_u32 val, epp_u32* pDst, epp_size length)
{
    return eppv_AndC_u32(pSrc, val, pDst, length);
}

static inline epp_Status AndC(const epp_u64* pSrc, epp_u64 val, epp_u64* pDst, epp_size length)
{
    return eppv_AndC_u64(pSrc, val, pDst, length);
}

static inline epp_Status OrC(const epp_u8* pSrc, epp_u8 val, epp_u8* pDst, epp_size length)
{
    return eppv_OrC_u8(pSrc, val, pDst, length);
}

static inline epp_Status OrC(const epp_u16* pSrc, epp_u16 val, epp_u16* pDst, epp_size length)
{
    return eppv_OrC_u16(pSrc, val, pDst, length);
}

static inline epp_Status OrC(const epp_u32* pSrc, epp_u32 val, epp_u32* pDst, epp_size length)
{
    return eppv_OrC_u32(pSrc, val, pDst, length);
}

static inline epp_Status OrC(const epp_u64* pSrc, epp_u64 val, epp_u64* pDst, epp_size length)
{
    return eppv_OrC_u64(pSrc, val, pDst, length);
}

static inline epp_Status XorC(const epp_u8* pSrc, epp_u8 val, epp_u8* pDst, epp_size length)
{
    return eppv_XorC_u8(pSrc, val, pDst, length);
}

static inline epp_Status XorC(const epp_u16* pSrc, epp_u16 val, epp_u16* pDst, epp_size length)
{
    return eppv_XorC_u16(pSrc, val, pDst, length);
}

static inline epp_Status XorC(const epp_u32* pSrc, epp_u32 val, epp_u32* pDst, epp_size length)
{
    return eppv_XorC_u32(pSrc, val, pDst, length);
}

static inline epp_Status XorC(const epp_u64* pSrc, epp_u64 val, epp_u64* pDst, epp_size length)
{
    return eppv_XorC_u64(pSrc, val, pDst, length);
}

static inline epp_Status AndC(const epp_s8* pSrc, epp_s8 val, epp_s8* pDst, epp_size length)
{
    return eppv_AndC_s8(pSrc, val, pDst, length);
}

static inline epp_Status AndC(const epp_s16* pSrc, epp_s16 val, epp_s16* pDst, epp_size length)
{
    return eppv_AndC_s16(pSrc, val, pDst, length);
}

static inline epp_Status AndC(const epp_s32* pSrc, epp_s32 val, epp_s32* pDst, epp_size length)
{
    return eppv_AndC_s32(pSrc, val, pDst, length);
}

static inline epp_Status AndC(const epp_s64* pSrc, epp_s64 val, epp_s64* pDst, epp_size length)
{
    return eppv_AndC_s64(pSrc, val, pDst, length);
}

static inline epp_Status AndC(const epp_cs16* pSrc, epp_cs16 val, epp_cs16* pDst, epp_size length)
{
    return eppv_AndC_cs16(pSrc, val, pDst, length);
}

static inline epp_Status AndC(const epp_cs32* pSrc, epp_cs32 val, epp_cs32* pDst, epp_size length)
{
    return eppv_AndC_cs32(pSrc, val, pDst, length);
}

static inline epp_Status OrC(const epp_s8* pSrc, epp_s8 val, epp_s8* pDst, epp_size length)
{
    return eppv_OrC_s8(pSrc, val, pDst, length);
}

static inline epp_Status OrC(const epp_s16* pSrc, epp_s16 val, epp_s16* pDst, epp_size length)
{
    return eppv_OrC_s16(pSrc, val, pDst, length);
}

static inline epp_Status OrC(const epp_s32* pSrc, epp_s32 val, epp_s32* pDst, epp_size length)
{
    return eppv_OrC_s32(pSrc, val, pDst, length);
}

static inline epp_Status OrC(const epp_s64* pSrc, epp_s64 val, epp_s64* pDst, epp_size length)
{
    return eppv_OrC_s64(pSrc, val, pDst, length);
}

static inline epp_Status OrC(const epp_cs16* pSrc, epp_cs16 val, epp_cs16* pDst, epp_size length)
{
    return eppv_OrC_cs16(pSrc, val, pDst, length);
}

static inline epp_Status OrC(const epp_cs32* pSrc, epp_cs32 val, epp_cs32* pDst, epp_size length)
{
    return eppv_OrC_cs32(pSrc, val, pDst, length);
}

static inline epp_Status XorC(const epp_s8* pSrc, epp_s8 val, epp_s8* pDst, epp_size length)
{
    return eppv_XorC_s8(pSrc, val, pDst, length);
}

static inline epp_Status XorC(const epp_s16* pSrc, epp_s16 val, epp_s16* pDst, epp_size length)
{
    return eppv_XorC_s16(pSrc, val, pDst, length);
}

static inline epp_Status XorC(const epp_s32* pSrc, epp_s32 val, epp_s32* pDst, epp_size length)
{
    return eppv_XorC_s32(pSrc, val, pDst, length);
}

static inline epp_Status XorC(const epp_s64* pSrc, epp_s64 val, epp_s64* pDst, epp_size length)
{
    return eppv_XorC_s64(pSrc, val, pDst, length);
}

static inline epp_Status XorC(const epp_cs16* pSrc, epp_cs16 val, epp_cs16* pDst, epp_size length)
{
    return eppv_XorC_cs16(pSrc, val, pDst, length);
}

static inline epp_Status XorC(const epp_cs32* pSrc, epp_cs32 val, epp_cs32* pDst, epp_size length)
{
    return eppv_XorC_cs32(pSrc, val, pDst, length);
}


/*
//  Name:        ShiftLC/ShiftRC
//  Purpose:     Computes the logical and arithmetic bit shift of vector's elements
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    shift      The shift value.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status ShiftLC(const epp_u8* pSrc, epp_size shift, epp_u8* pDst, epp_size length)
{
    return eppv_ShiftLC_u8(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftLC(const epp_u16* pSrc, epp_size shift, epp_u16* pDst, epp_size length)
{
    return eppv_ShiftLC_u16(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftLC(const epp_u32* pSrc, epp_size shift, epp_u32* pDst, epp_size length)
{
    return eppv_ShiftLC_u32(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftLC(const epp_u64* pSrc, epp_size shift, epp_u64* pDst, epp_size length)
{
    return eppv_ShiftLC_u64(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftLC(const epp_s8* pSrc, epp_size shift, epp_s8* pDst, epp_size length)
{
    return eppv_ShiftLC_s8(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftLC(const epp_s16* pSrc, epp_size shift, epp_s16* pDst, epp_size length)
{
    return eppv_ShiftLC_s16(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftLC(const epp_s32* pSrc, epp_size shift, epp_s32* pDst, epp_size length)
{
    return eppv_ShiftLC_s32(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftLC(const epp_s64* pSrc, epp_size shift, epp_s64* pDst, epp_size length)
{
    return eppv_ShiftLC_s64(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftLC(const epp_cs16* pSrc, epp_size shift, epp_cs16* pDst, epp_size length)
{
    return eppv_ShiftLC_cs16(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftLC(const epp_cs32* pSrc, epp_size shift, epp_cs32* pDst, epp_size length)
{
    return eppv_ShiftLC_cs32(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftRC(const epp_u8* pSrc, epp_size shift, epp_u8* pDst, epp_size length)
{
    return eppv_ShiftRC_u8(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftRC(const epp_u16* pSrc, epp_size shift, epp_u16* pDst, epp_size length)
{
    return eppv_ShiftRC_u16(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftRC(const epp_u32* pSrc, epp_size shift, epp_u32* pDst, epp_size length)
{
    return eppv_ShiftRC_u32(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftRC(const epp_u64* pSrc, epp_size shift, epp_u64* pDst, epp_size length)
{
    return eppv_ShiftRC_u64(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftRC(const epp_s8* pSrc, epp_size shift, epp_s8* pDst, epp_size length)
{
    return eppv_ShiftRC_s8(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftRC(const epp_s16* pSrc, epp_size shift, epp_s16* pDst, epp_size length)
{
    return eppv_ShiftRC_s16(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftRC(const epp_s32* pSrc, epp_size shift, epp_s32* pDst, epp_size length)
{
    return eppv_ShiftRC_s32(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftRC(const epp_s64* pSrc, epp_size shift, epp_s64* pDst, epp_size length)
{
    return eppv_ShiftRC_s64(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftRC(const epp_cs16* pSrc, epp_size shift, epp_cs16* pDst, epp_size length)
{
    return eppv_ShiftRC_cs16(pSrc, shift, pDst, length);
}

static inline epp_Status ShiftRC(const epp_cs32* pSrc, epp_size shift, epp_cs32* pDst, epp_size length)
{
    return eppv_ShiftRC_cs32(pSrc, shift, pDst, length);
}


/*
//  Name:        NormC/L1/L2
//  Purpose:     Calculates the norm of vector
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    length     The length of vector.
//    pNorm      The resulting norm.
//  Notes:
*/
static inline epp_Status NormC(const epp_s16* pSrc, epp_size length, epp_u16* pNorm)
{
    return eppv_NormC_s16(pSrc, length, pNorm);
}

static inline epp_Status NormC(const epp_s32* pSrc, epp_size length, epp_u32* pNorm)
{
    return eppv_NormC_s32(pSrc, length, pNorm);
}

static inline epp_Status NormC(const epp_f16* pSrc, epp_size length, epp_f16* pNorm)
{
    return eppv_NormC_f16(pSrc, length, pNorm);
}

static inline epp_Status NormC(const epp_f32* pSrc, epp_size length, epp_f32* pNorm)
{
    return eppv_NormC_f32(pSrc, length, pNorm);
}

static inline epp_Status NormC(const epp_f64* pSrc, epp_size length, epp_f64* pNorm)
{
    return eppv_NormC_f64(pSrc, length, pNorm);
}

static inline epp_Status NormL1(const epp_s16* pSrc, epp_size length, epp_u64* pNorm)
{
    return eppv_NormL1_s16(pSrc, length, pNorm);
}

static inline epp_Status NormL1(const epp_s32* pSrc, epp_size length, epp_u64* pNorm)
{
    return eppv_NormL1_s32(pSrc, length, pNorm);
}

static inline epp_Status NormL1(const epp_f16* pSrc, epp_size length, epp_f32* pNorm)
{
    return eppv_NormL1_f16(pSrc, length, pNorm);
}

static inline epp_Status NormL1(const epp_f32* pSrc, epp_size length, epp_f32* pNorm)
{
    return eppv_NormL1_f32(pSrc, length, pNorm);
}

static inline epp_Status NormL1(const epp_f64* pSrc, epp_size length, epp_f64* pNorm)
{
    return eppv_NormL1_f64(pSrc, length, pNorm);
}

static inline epp_Status NormL2(const epp_s16* pSrc, epp_size length, epp_f32* pNorm)
{
    return eppv_NormL2_s16(pSrc, length, pNorm);
}

static inline epp_Status NormL2(const epp_s32* pSrc, epp_size length, epp_f32* pNorm, epp_size scale)
{
    return eppv_NormL2_s32_N(pSrc, length, pNorm, scale);
}

static inline epp_Status NormL2_f16(const epp_f16* pSrc, epp_size length, epp_f32* pNorm)
{
    return eppv_NormL2_f16(pSrc, length, pNorm);
}

static inline epp_Status NormL2(const epp_f32* pSrc, epp_size length, epp_f32* pNorm)
{
    return eppv_NormL2_f32(pSrc, length, pNorm);
}

static inline epp_Status NormL2(const epp_f64* pSrc, epp_size length, epp_f64* pNorm)
{
    return eppv_NormL2_f64(pSrc, length, pNorm);
}


/*
//  Name:        NormDiffC/L1/L2
//  Purpose:     Calculates the C, L1, L2 norm of difference of two vectors
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc1      The first sourse vector data pointer.
//    pSrc2      The second sourse vector data pointer.
//    length     The length of vector.
//    pNorm      The norm of difference.
//  Notes:
*/
static inline epp_Status NormDiffC(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_size length, epp_f16* pNorm)
{
    return eppv_NormDiffC_f16(pSrc1, pSrc2, length, pNorm);
}

static inline epp_Status NormDiffC(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_size length, epp_f32* pNorm)
{
    return eppv_NormDiffC_f32(pSrc1, pSrc2, length, pNorm);
}

static inline epp_Status NormDiffL1(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_size length, epp_f32* pNorm)
{
    return eppv_NormDiffL1_f16(pSrc1, pSrc2, length, pNorm);
}

static inline epp_Status NormDiffL1(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_size length, epp_f32* pNorm)
{
    return eppv_NormDiffL1_f32(pSrc1, pSrc2, length, pNorm);
}

static inline epp_Status NormDiffL2(const epp_f16* pSrc1, const epp_f16* pSrc2, epp_size length, epp_f32* pNorm)
{
    return eppv_NormDiffL2_f16(pSrc1, pSrc2, length, pNorm);
}

static inline epp_Status NormDiffL2(const epp_f32* pSrc1, const epp_f32* pSrc2, epp_size length, epp_f32* pNorm)
{
    return eppv_NormDiffL2_f32(pSrc1, pSrc2, length, pNorm);
}


/*
//  Name:        Mean
//  Purpose:     Calculates the mean value of vector
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    length     The length of vector.
//    pMean      The resulting value.
//  Notes:
*/
static inline epp_Status Mean(const epp_s16* pSrc, epp_size length, epp_f32* pMean)
{
    return eppv_Mean_s16(pSrc, length, pMean);
}

static inline epp_Status Mean(const epp_s32* pSrc, epp_size length, epp_f32* pMean)
{
    return eppv_Mean_s32(pSrc, length, pMean);
}

static inline epp_Status Mean_f16(const epp_f16* pSrc, epp_size length, epp_f32* pMean)
{
    return eppv_Mean_f16(pSrc, length, pMean);
}

static inline epp_Status Mean(const epp_f32* pSrc, epp_size length, epp_f32* pMean)
{
    return eppv_Mean_f32(pSrc, length, pMean);
}

static inline epp_Status Mean(const epp_f64* pSrc, epp_size length, epp_f64* pMean)
{
    return eppv_Mean_f64(pSrc, length, pMean);
}


/*
//  Name:        VarianceBiased
//  Purpose:     Calculates the biased variance of vector
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    mean       The mean value of vector elements.
//    length     The length of vector.
//    pVar       The biased variance.
//  Notes:
*/
static inline epp_Status VarianceBiased(const epp_f16* pSrc, epp_f16 mean, epp_size length, epp_f32* pVar)
{
    return eppv_VarianceBiased_f16(pSrc, mean, length, pVar);
}
static inline epp_Status VarianceBiased(const epp_f32* pSrc, epp_f32 mean, epp_size length, epp_f32* pVar)
{
    return eppv_VarianceBiased_f32(pSrc, mean, length, pVar);
}


/*
//  Name:        eppv_VarianceUnbiased
//  Purpose:     Calculates the unbiased variance of vector
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length < 2
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    mean       The mean value of vector elements.
//    length     The length of vector.
//    pVar       The unbiased variance.
//  Notes:
*/
static inline epp_Status VarianceUnbiased(const epp_f16* pSrc, epp_f16 mean, epp_size length, epp_f32* pVar)
{
    return eppv_VarianceUnbiased_f16(pSrc, mean, length, pVar);
}
static inline epp_Status VarianceUnbiased(const epp_f32* pSrc, epp_f32 mean, epp_size length, epp_f32* pVar)
{
    return eppv_VarianceUnbiased_f32(pSrc, mean, length, pVar);
}


/*
//  Name:        eppv_StdDevBiased
//  Purpose:     Calculates the biased standard deviation of vector
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length == 0
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    mean       The mean value of vector elements.
//    length     The length of vector.
//    pDev       The biased standard deviation.
//  Notes:
*/
static inline epp_Status StdDevBiased(const epp_f16* pSrc, epp_f16 mean, epp_size length, epp_f32* pDev)
{
    return eppv_StdDevBiased_f16(pSrc, mean, length, pDev);
}
static inline epp_Status StdDevBiased(const epp_f32* pSrc, epp_f32 mean, epp_size length, epp_f32* pDev)
{
    return eppv_StdDevBiased_f32(pSrc, mean, length, pDev);
}


/*
//  Name:        eppv_StdDevUnbiased
//  Purpose:     Calculates the unbiased standard deviation of vector
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsBadParamsErr  length < 2
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    mean       The mean value of vector elements.
//    length     The length of vector.
//    pDev       The unbiased standard deviation.
//  Notes:
*/
static inline epp_Status StdDevUnbiased(const epp_f16* pSrc, epp_f16 mean, epp_size length, epp_f32* pDev)
{
    return eppv_StdDevUnbiased_f16(pSrc, mean, length, pDev);
}
static inline epp_Status StdDevUnbiased(const epp_f32* pSrc, epp_f32 mean, epp_size length, epp_f32* pDev)
{
    return eppv_StdDevUnbiased_f32(pSrc, mean, length, pDev);
}


/*
//  Name:        Round
//  Purpose:     Computes rounded values of vector elements
//  Returns:     epp_Status
//    epp_StsOK            Ok
//    epp_StsRoundModeErr  Unsupported round mode
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//    roundMode  The round mode.
//  Notes:
*/
static inline epp_Status Round(const epp_f16* pSrc, epp_f16* pDst, epp_size length, epp_RoundMode roundMode)
{
    return eppv_Round_f16(pSrc, pDst, length, roundMode);
}

static inline epp_Status Round(const epp_f32* pSrc, epp_f32* pDst, epp_size length, epp_RoundMode roundMode)
{
    return eppv_Round_f32(pSrc, pDst, length, roundMode);
}

static inline epp_Status Round(const epp_f64* pSrc, epp_f64* pDst, epp_size length, epp_RoundMode roundMode)
{
    return eppv_Round_f64(pSrc, pDst, length, roundMode);
}

static inline epp_Status Round(const epp_cf16* pSrc, epp_cf16* pDst, epp_size length, epp_RoundMode roundMode)
{
    return eppv_Round_cf16(pSrc, pDst, length, roundMode);
}

static inline epp_Status Round(const epp_cf32* pSrc, epp_cf32* pDst, epp_size length, epp_RoundMode roundMode)
{
    return eppv_Round_f32((epp_f32*)pSrc, (epp_f32*)pDst, length * 2, roundMode);
}

static inline epp_Status Round(const epp_cf64* pSrc, epp_cf64* pDst, epp_size length, epp_RoundMode roundMode)
{
    return eppv_Round_f64((epp_f64*)pSrc, (epp_f64*)pDst, length * 2, roundMode);
}


/*
//  Name:        Conj
//  Purpose:     Calculates conjugation of vector elements
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Conj_S(const epp_cs16* pSrc, epp_cs16* pDst, epp_size length)
{
    return eppv_Conj_cs16_S(pSrc, pDst, length);
}

static inline epp_Status Conj_S(const epp_cs32* pSrc, epp_cs32* pDst, epp_size length)
{
    return eppv_Conj_cs32_S(pSrc, pDst, length);
}

static inline epp_Status Conj(const epp_cf16* pSrc, epp_cf16* pDst, epp_size length)
{
    return eppv_Conj_cf16(pSrc, pDst, length);
}

static inline epp_Status Conj(const epp_cf32* pSrc, epp_cf32* pDst, epp_size length)
{
    return eppv_Conj_cf32(pSrc, pDst, length);
}

static inline epp_Status Conj(const epp_cf64* pSrc, epp_cf64* pDst, epp_size length)
{
    return eppv_Conj_cf64(pSrc, pDst, length);
}


/*
//  Name:        eppv_ConjSym
//  Purpose:     Calculates conjugation of vector elements and store them in reverse order (conjugate symmetry)
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status ConjSym(const epp_cf16* pSrc, epp_cf16* pDst, epp_size length)
{
    return eppv_ConjSym_cf16(pSrc, pDst, length);
}

static inline epp_Status ConjSym(const epp_cf32* pSrc, epp_cf32* pDst, epp_size length)
{
    return eppv_ConjSym_cf32(pSrc, pDst, length);
}

static inline epp_Status ConjSym(const epp_cf64* pSrc, epp_cf64* pDst, epp_size length)
{
    return eppv_ConjSym_cf64(pSrc, pDst, length);
}


/*
//  Name:        ThresholdLT
//  Purpose:     Limits vector elements by threshold (pDst[i] = (pSrc[i] < val) ? val : pSrc[i])
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    tVal       The threshold value.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status ThresholdLT(const epp_s16* pSrc, epp_s16 tVal, epp_s16* pDst, epp_size length)
{
    return eppv_ThresholdLT_s16(pSrc, tVal, pDst, length);
}

static inline epp_Status ThresholdLT(const epp_s32* pSrc, epp_s32 tVal, epp_s32* pDst, epp_size length)
{
    return eppv_ThresholdLT_s32(pSrc, tVal, pDst, length);
}

static inline epp_Status ThresholdLT_f16(const epp_f16* pSrc, epp_f16 tVal, epp_f16* pDst, epp_size length)
{
    return eppv_ThresholdLT_f16(pSrc, tVal, pDst, length);
}

static inline epp_Status ThresholdLT(const epp_f32* pSrc, epp_f32 tVal, epp_f32* pDst, epp_size length)
{
    return eppv_ThresholdLT_f32(pSrc, tVal, pDst, length);
}

static inline epp_Status ThresholdLT(const epp_f64* pSrc, epp_f64 tVal, epp_f64* pDst, epp_size length)
{
    return eppv_ThresholdLT_f64(pSrc, tVal, pDst, length);
}


/*
//  Name:        ThresholdGT
//  Purpose:     Limits vector elements by threshold (pDst[i] = (pSrc[i] > val) ? val : pSrc[i])
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    tVal       The threshold value.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status ThresholdGT(const epp_s16* pSrc, epp_s16 tVal, epp_s16* pDst, epp_size length)
{
    return eppv_ThresholdGT_s16(pSrc, tVal, pDst, length);
}

static inline epp_Status ThresholdGT(const epp_s32* pSrc, epp_s32 tVal, epp_s32* pDst, epp_size length)
{
    return eppv_ThresholdGT_s32(pSrc, tVal, pDst, length);
}

static inline epp_Status ThresholdGT_f16(const epp_f16* pSrc, epp_f16 tVal, epp_f16* pDst, epp_size length)
{
    return eppv_ThresholdGT_f16(pSrc, tVal, pDst, length);
}

static inline epp_Status ThresholdGT(const epp_f32* pSrc, epp_f32 tVal, epp_f32* pDst, epp_size length)
{
    return eppv_ThresholdGT_f32(pSrc, tVal, pDst, length);
}

static inline epp_Status ThresholdGT(const epp_f64* pSrc, epp_f64 tVal, epp_f64* pDst, epp_size length)
{
    return eppv_ThresholdGT_f64(pSrc, tVal, pDst, length);
}


/*
//  Name:        SwapBytes
//  Purpose:     Inverts the byte order of vector elements
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status SwapBytes(const epp_u16* pSrc, epp_u16* pDst, epp_size length)
{
    return eppv_SwapBytes_u16(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_u32* pSrc, epp_u32* pDst, epp_size length)
{
    return eppv_SwapBytes_u32(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_u64* pSrc, epp_u64* pDst, epp_size length)
{
    return eppv_SwapBytes_u64(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_s16* pSrc, epp_s16* pDst, epp_size length)
{
    return eppv_SwapBytes_s16(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_s32* pSrc, epp_s32* pDst, epp_size length)
{
    return eppv_SwapBytes_s32(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_s64* pSrc, epp_s64* pDst, epp_size length)
{
    return eppv_SwapBytes_s64(pSrc, pDst, length);
}

static inline epp_Status SwapBytes_f16(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_SwapBytes_f16(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_SwapBytes_f32(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_f64* pSrc, epp_f64* pDst, epp_size length)
{
    return eppv_SwapBytes_f64(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_cs16* pSrc, epp_cs16* pDst, epp_size length)
{
    return eppv_SwapBytes_cs16(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_cs32* pSrc, epp_cs32* pDst, epp_size length)
{
    return eppv_SwapBytes_cs32(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_cs64* pSrc, epp_cs64* pDst, epp_size length)
{
    return eppv_SwapBytes_cs64(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_cf16* pSrc, epp_cf16* pDst, epp_size length)
{
    return eppv_SwapBytes_cf16(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_cf32* pSrc, epp_cf32* pDst, epp_size length)
{
    return eppv_SwapBytes_cf32(pSrc, pDst, length);
}

static inline epp_Status SwapBytes(const epp_cf64* pSrc, epp_cf64* pDst, epp_size length)
{
    return eppv_SwapBytes_cf64(pSrc, pDst, length);
}


/*
//  Name:        Flip
//  Purpose:     Inverts the vector element's order, pDst[i] = pSrc[length - 1 - i]
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status Flip(const epp_u16* pSrc, epp_u16* pDst, epp_size length)
{
    return eppv_Flip_u16(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_u32* pSrc, epp_u32* pDst, epp_size length)
{
    return eppv_Flip_u32(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_u64* pSrc, epp_u64* pDst, epp_size length)
{
    return eppv_Flip_u64(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_s16* pSrc, epp_s16* pDst, epp_size length)
{
    return eppv_Flip_s16(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_s32* pSrc, epp_s32* pDst, epp_size length)
{
    return eppv_Flip_s32(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_s64* pSrc, epp_s64* pDst, epp_size length)
{
    return eppv_Flip_s64(pSrc, pDst, length);
}

static inline epp_Status Flip_f16(const epp_f16* pSrc, epp_f16* pDst, epp_size length)
{
    return eppv_Flip_f16(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_Flip_f32(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_f64* pSrc, epp_f64* pDst, epp_size length)
{
    return eppv_Flip_f64(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_cs16* pSrc, epp_cs16* pDst, epp_size length)
{
    return eppv_Flip_cs16(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_cs32* pSrc, epp_cs32* pDst, epp_size length)
{
    return eppv_Flip_cs32(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_cs64* pSrc, epp_cs64* pDst, epp_size length)
{
    return eppv_Flip_cs64(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_cf16* pSrc, epp_cf16* pDst, epp_size length)
{
    return eppv_Flip_cf16(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_cf32* pSrc, epp_cf32* pDst, epp_size length)
{
    return eppv_Flip_cf32(pSrc, pDst, length);
}

static inline epp_Status Flip(const epp_cf64* pSrc, epp_cf64* pDst, epp_size length)
{
    return eppv_Flip_cf64(pSrc, pDst, length);
}


/*
//  Name:        eppv_RealToComplex
//  Purpose:     Creates complex vector from real and imaginary vectors
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrcRe     Pointer to the vector with real part of complex elements. If pDstRe == NULL then 0 is used as real part of elements.
//    pSrcIm     Pointer to the vector with imaginary part of complex elements. If pDstIm == NULL then 0 is used as imaginary part of elements.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status RealToComplex_f16cf16(const epp_f16* pSrcRe, const epp_f16* pSrcIm, epp_cf16* pDst, epp_size length)
{
    return eppv_RealToComplex_f16cf16(pSrcRe, pSrcIm, pDst, length);
}

static inline epp_Status RealToComplex(const epp_f32* pSrcRe, const epp_f32* pSrcIm, epp_cf32* pDst, epp_size length)
{
    return eppv_RealToComplex_f32cf32(pSrcRe, pSrcIm, pDst, length);
}

static inline epp_Status RealToComplex(const epp_f64* pSrcRe, const epp_f64* pSrcIm, epp_cf64* pDst, epp_size length)
{
    return eppv_RealToComplex_f64cf64(pSrcRe, pSrcIm, pDst, length);
}

static inline epp_Status RealToComplex(const epp_s16* pSrcRe, const epp_s16* pSrcIm, epp_cs16* pDst, epp_size length)
{
    return eppv_RealToComplex_s16cs16(pSrcRe, pSrcIm, pDst, length);
}

static inline epp_Status RealToComplex(const epp_s32* pSrcRe, const epp_s32* pSrcIm, epp_cs32* pDst, epp_size length)
{
    return eppv_RealToComplex_s32cs32(pSrcRe, pSrcIm, pDst, length);
}

static inline epp_Status RealToComplex(const epp_s64* pSrcRe, const epp_s64* pSrcIm, epp_cs64* pDst, epp_size length)
{
    return eppv_RealToComplex_s64cs64(pSrcRe, pSrcIm, pDst, length);
}


/*
//  Name:        eppv_ComplexToReal
//  Purpose:     Creates vectors with real and imaginary parts of complex vector
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       Pointer to the complex vector.
//    pDstRe     Pointer to the destination vector with real part of complex elements. If pDstRe == NULL then real part is skipped.
//    pDstIm     Pointer to the destination vector with imaginary part of complex elements. If pDstIm == NULL then imaginary part is skipped.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status ComplexToReal_cf16f16(const epp_cf16* pSrc, epp_f16* pDstRe, epp_f16* pDstIm, epp_size length)
{
    return eppv_ComplexToReal_cf16f16(pSrc, pDstRe, pDstIm, length);
}

static inline epp_Status ComplexToReal(const epp_cf32* pSrc, epp_f32* pDstRe, epp_f32* pDstIm, epp_size length)
{
    return eppv_ComplexToReal_cf32f32(pSrc, pDstRe, pDstIm, length);
}

static inline epp_Status ComplexToReal(const epp_cf64* pSrc, epp_f64* pDstRe, epp_f64* pDstIm, epp_size length)
{
    return eppv_ComplexToReal_cf64f64(pSrc, pDstRe, pDstIm, length);
}

static inline epp_Status ComplexToReal(const epp_cs16* pSrc, epp_s16* pDstRe, epp_s16* pDstIm, epp_size length)
{
    return eppv_ComplexToReal_cs16s16(pSrc, pDstRe, pDstIm, length);
}

static inline epp_Status ComplexToReal(const epp_cs32* pSrc, epp_s32* pDstRe, epp_s32* pDstIm, epp_size length)
{
    return eppv_ComplexToReal_cs32s32(pSrc, pDstRe, pDstIm, length);
}

static inline epp_Status ComplexToReal(const epp_cs64* pSrc, epp_s64* pDstRe, epp_s64* pDstIm, epp_size length)
{
    return eppv_ComplexToReal_cs64s64(pSrc, pDstRe, pDstIm, length);
}


/*
//  Name:        eppv_SwapEvenOdd
//  Purpose:     Swaps even and odd vector elements (d[0]=s[1], d[1]=s[0], d[2]=s[3], d[3]=s[2], ...)
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  Ok
//    epp_StsBadParamsErr  length is odd
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status SwapEvenOdd(const epp_u16* pSrc, epp_u16* pDst, epp_size length)
{
    return eppv_SwapEvenOdd_u16(pSrc, pDst, length);
}

static inline epp_Status SwapEvenOdd(const epp_u32* pSrc, epp_u32* pDst, epp_size length)
{
    return eppv_SwapEvenOdd_u32(pSrc, pDst, length);
}

static inline epp_Status SwapEvenOdd(const epp_u64* pSrc, epp_u64* pDst, epp_size length)
{
    return eppv_SwapEvenOdd_u64(pSrc, pDst, length);
}

static inline epp_Status SwapEvenOdd(const epp_s16* pSrc, epp_s16* pDst, epp_size length)
{
    return eppv_SwapEvenOdd_s16(pSrc, pDst, length);
}

static inline epp_Status SwapEvenOdd(const epp_s32* pSrc, epp_s32* pDst, epp_size length)
{
    return eppv_SwapEvenOdd_s32(pSrc, pDst, length);
}

static inline epp_Status SwapEvenOdd(const epp_s64* pSrc, epp_s64* pDst, epp_size length)
{
    return eppv_SwapEvenOdd_s64(pSrc, pDst, length);
}

static inline epp_Status SwapEvenOdd(const epp_f32* pSrc, epp_f32* pDst, epp_size length)
{
    return eppv_SwapEvenOdd_f32(pSrc, pDst, length);
}

static inline epp_Status SwapEvenOdd(const epp_f64* pSrc, epp_f64* pDst, epp_size length)
{
    return eppv_SwapEvenOdd_f64(pSrc, pDst, length);
}


/*
//  Name:        eppv_SwapReIm
//  Purpose:     Swaps Re and Im parts of vector elements (d[0].re=s[0].im, d[0].im=s[0].re, ...)
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  Ok
//  Parameters:
//    pSrc       The sourse vector data pointer.
//    pDst       The destination vector data pointer.
//    length     The length of vectors.
//  Notes:
*/
static inline epp_Status SwapReIm(const epp_cs16* pSrc, epp_cs16* pDst, epp_size length)
{
    return eppv_SwapReIm_cs16(pSrc, pDst, length);
}

static inline epp_Status SwapReIm(const epp_cs32* pSrc, epp_cs32* pDst, epp_size length)
{
    return eppv_SwapReIm_cs32(pSrc, pDst, length);
}

static inline epp_Status SwapReIm(const epp_cs64* pSrc, epp_cs64* pDst, epp_size length)
{
    return eppv_SwapReIm_cs64(pSrc, pDst, length);
}

static inline epp_Status SwapReIm(const epp_cf16* pSrc, epp_cf16* pDst, epp_size length)
{
    return eppv_SwapReIm_cf16(pSrc, pDst, length);
}

static inline epp_Status SwapReIm(const epp_cf32* pSrc, epp_cf32* pDst, epp_size length)
{
    return eppv_SwapReIm_cf32(pSrc, pDst, length);
}

static inline epp_Status SwapReIm(const epp_cf64* pSrc, epp_cf64* pDst, epp_size length)
{
    return eppv_SwapReIm_cf64(pSrc, pDst, length);
}


} // namespace eppv
